#########
Model API
#########

.. autoclass:: datarobot.models.Model
   :members:
   :exclude-members: from_server_data

##############
PrimeModel API
##############

.. autoclass:: datarobot.models.PrimeModel
   :inherited-members:
   :members:
   :exclude-members: from_server_data, request_frozen_model, request_frozen_datetime_model, train, train_datetime, request_approximation

################
BlenderModel API
################

.. autoclass:: datarobot.models.BlenderModel
   :members:
   :inherited-members:
   :exclude-members: from_server_data


#################
DatetimeModel API
#################
.. _datetime_mod:

.. autoclass:: datarobot.models.DatetimeModel
   :inherited-members:
   :members:
   :exclude-members: from_server_data, train, request_frozen_model

####################
RatingTableModel API
####################

.. autoclass:: datarobot.models.RatingTableModel
   :inherited-members:
   :members:
   :exclude-members: from_server_data

###################
Advanced Tuning API
###################

.. autoclass:: datarobot.models.advanced_tuning.AdvancedTuningSession
   :members:
